@@ -2,6 +2,7 @@ import math
 import json
 import logging
 from pydantic import BaseModel
+import yaml
 
 
 class GPSPin(BaseModel):
@@ -136,6 +137,80 @@ def geojson_to_poly(gjson: str, name: str = None):
     return '\n'.join(output)
 
 
+def geojson_to_yaml_obj(gjson: str, name: str = None):
+    loaded = json.loads(gjson)
+    if not name:
+        if 'name' in loaded:
+            name = loaded['name']
+        else:
+            name = 'default'
+    result = {
+        "id": name,
+        "polygons": []
+    }
+
+    features = loaded['features']
+    for f in features:
+        geometry = f['geometry']
+        if geometry['type'] != 'Polygon':
+            raise ValueError('only converting from geojson polygon is supported')
+        if len(geometry['coordinates']) > 1:
+            logging.warn(
+                'multiple coordinates of polygon detected, only using first one as exterior definition')
+
+        polygon = {
+            "name": "area1",
+            "coords": []
+        }
+        for coord in geometry['coordinates'][0]:
+            polygon["coords"].append({"lng": coord[0], "lat": coord[1]})
+
+        result["polygons"].append(polygon)
+
+    return result
+
+
+def geojson_to_yaml(gjson: str, name: str = None):
+    return yaml.dump(geojson_to_yaml_obj(gjson, name))
+
+
+def yaml_to_geojson(yaml_str: str, name: str):
+    obj = yaml.load(yaml_str)
+
+    loaded = None
+    for area in obj["areas"]:
+        if area['id'] == name:
+            loaded = area
+            break
+
+    if not loaded:
+        raise ValueError(f'name not found: {name}')
+
+    result = {
+        "type": "FeatureCollection",
+        "features": []
+    }
+
+    polygons = loaded['polygons']
+    for polygon in polygons:
+        geometry = {
+            'type': "Polygon",
+            "coordinates": [
+                []
+            ]
+        }
+        for coord in polygon['coords']:
+            geometry["coordinates"][0].append([coord['lng'],coord['lat']])
+
+        result["features"].append({
+            "type": "Feature",
+            "properties": {},
+            "geometry": geometry
+        })
+
+    return json.dumps(result)
+
+
 def poly_to_geojson(poly: str):
     gjson = {
         'type': 'FeatureCollection',
@@ -187,3 +262,9 @@ def parse_poly(pstr: str):
             result.append(coords)
             coords = []
     return result
+
+
+if __name__ == "__main__":
+    for name in ["indonesia"]:
+        print(geojson_to_yaml(open(f'/Users/lifuwu/Desktop/maaas/{name}.geojson').read(), name))
+    # print(yaml_to_geojson(open('/Users/lifuwu/Desktop/maaas/maaas-area-cfg.yaml').read(), "pakistan"))
