@@ -3,12 +3,8 @@ from .geo import GPSPin, cleanse, split_trips
 
 
 def test_parse_poly():
-    thing = """who
-cares
-\t1.2\t3.4
-\t5.6\t7.8
-END 
-END """
+    thing = 'who\ncares\n\t1.2\t3.4\n\t5.6\t7.8\nEND\nEND'
+
     r = geo.parse_poly(thing)
     print(f'r is {r}')
     assert len(r) == 1
